#
# spec file for package kubefirst
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           kubefirst
Version:        2.7.9
Release:        1.1
Summary:        CLI for the KubeFirst GitOps Infrastructure & Application Delivery Platform
License:        MIT
URL:            https://github.com/kubefirst/kubefirst
Source:         kubefirst-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  bash-completion
BuildRequires:  fish
BuildRequires:  go >= 1.18
BuildRequires:  zsh

%description
The Kubefirst CLI creates instant GitOps platforms that integrate some of the
best tools in cloud native from scratch in minutes.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1

%build
DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags="-X github.com/kubefirst/runtime/configs.K1Version=v%{version}" \
   -o bin/kubefirst

%install
# Install the binary.
install -D -m 0755 bin/%{name} "%{buildroot}/%{_bindir}/%{name}"

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh/site-functions/
%{buildroot}/%{_bindir}/%{name} completion zsh > %{buildroot}%{_datarootdir}/zsh/site-functions/_%{name}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%files -n %{name}-bash-completion
%{_datarootdir}/bash-completion/completions/%{name}

%files -n %{name}-fish-completion
%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

%files -n %{name}-zsh-completion
%{_datarootdir}/zsh/site-functions/_%{name}

%changelog
* Fri Dec 13 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.7.9:
  * set next macro chart for kubefirst - 2.7.9
* Thu Dec 12 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.7.8:
  * fix: delete kubefirst file when doing kubefirst reset - KRA-73
    (#2344)
  * chore: remove unused GitHub Workflow for devrel (#2346)
  * docs: add azure to the readme (#2343)
  * update role name docs (#2327)
  * fix(azure): make the dns resource group optional (#2339)
* Fri Nov 29 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.7.7:
  * revert bubbletea changes
* Fri Nov 29 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.7.6:
  * set next macro chart for kubefirst - 2.7.6
  * Bump Go versions.
  * remove stat
  * fix: delete k1dir instead of kubeconfig file
* Fri Nov 22 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.7.5:
  * set next macro chart for kubefirst - 2.7.5
  * bump api (#2326)
  * update blog link (#2325)
  * fix: delete k1dir instead of kubeconfig file
* Tue Nov 12 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.7.4:
  * set next macro chart for kubefirst - 2.7.4
  * Add Azure to beta command (#2291)
  * set next macro chart for kubefirst - 2.7.4-rc3
  * set next macro chart for kubefirst - 2.7.4-rc2
  * set next macro chart for kubefirst - 2.7.4-rc1
* Tue Oct 29 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.7.3:
  * set next macro chart for kubefirst - 2.7.3
  * set next macro chart for kubefirst - 2.7.3-rc3
  * set next macro chart for kubefirst - 2.7.3-rc2
  * set next macro chart for kubefirst - 2.7.3-rc1
* Tue Oct 29 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.7.2 (there is no 2.7.1):
  * set next macro chart for kubefirst - 2.7.2
  * feat: change tag
  * set next macro chart for kubefirst - 2.7.2-rc1
  * set next macro chart for kubefirst - 2.7.1-rc3
  * set next macro chart for kubefirst - 2.7.1-rc2
  * set next macro chart for kubefirst - 2.7.1-rc1
* Fri Oct 25 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.7.0:
  * feat: tag api to latest version
  * fix: retry (#2311)
  * fix: k3d
  * feat: update doc links to kubefirst.konstruct.io/docs (#2306)
  * fix: launch deployed message (#2305)
  * upgrade Kubefirst API to latest (#2303)
  * upgrade Kubefirst API to latest (#2302)
  * Reference tagged version of the SDK.
  * feat: update vault-handler manifest source to konstructio
    (#2289)
  * fix typo
  * add dependencies
  * fix: bypass if directory already exists
  * set next macro chart for kubefirst - 2.6.2-rc2
  * Fix linter issues.
  * Bump Kubefirst API SDK version.
  * set next macro chart for kubefirst - 2.6.2-rc1
  * Fixes to error handling.
  * Fix typo in function name.
  * fix(google): fix typo (#2285)
  * use progress success function
  * handle nil in switch
  * fix reset cmd
  * Fix incorrect printing statement.
  * Update using final standard linters
  * Fix compilation
  * Cleanup internal folder
  * Fix version printing.
  * Enable golangci-lint
  * Clean up code using GolangCI-Lint
* Sat Sep 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.6.1:
  * set next macro chart for kubefirst - 2.6.1
* Sat Sep 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.6.0:
  * set next macro chart for kubefirst - 2.6.0
  * Add missing formatted file.
  * Change version on CI too
  * Remove unused functions. Bump to Go 1.23. Run `gofmt` on all
    files.
  * fix: devel (#2276)
* Sat Sep 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.5.11:
  * set next macro chart for kubefirst - 2.5.11
* Sat Sep 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.5.10:
  * set next macro chart for kubefirst - 2.5.10
* Sat Sep 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.5.9 (no releases between 2.5.3 and this one):
  * set next macro chart for kubefirst - 2.5.9
  * remove v so regex matches again (#2275)
  * fix bad chart ref from kubefirst and emails (#2274)
* Sat Sep 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.5.3 (no release 2.5.2):
  * set next macro chart for kubefirst - 2.5.3
* Sat Sep 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.5.1:
  * set next macro chart for kubefirst - 2.5.1
* Sat Sep 14 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.5.0:
  * use generated release notes for gitops-template (#2271)
  * replace kubefirst refs with konstructio (#2270)
  * removed duplicate
  * set next macro chart for kubefirst - 2.5.0
  * Fix linting messages.
  * Add conditions based on the situation.
  * refer latest kubefirst-api
  * add restart function for argo
  * reference to konstruct
  * fix:description
  * fix: akamai pro feature flag
* Fri Aug 16 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.4.17:
  * set next macro chart for kubefirst - 2.4.17
  * set next macro chart for kubefirst - 2.4.17-rc5
  * set next macro chart for kubefirst - 2.4.17-rc4
  * set next macro chart for kubefirst - 2.4.17-rc3
  * set next macro chart for kubefirst - 2.4.16-rc5
  * set next macro chart for kubefirst - 2.4.16-rc4
  * set next macro chart for kubefirst - 2.4.16-rc3
  * set next macro chart for kubefirst - 2.4.16-rc1
  * docs: update the local testing to reflect latest changes in the
    process (#2263)
* Thu Aug  8 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.4.16:
  * set next macro chart for kubefirst - 2.4.16
  * set next macro chart for kubefirst - 2.4.16-rc2
  * set next macro chart for kubefirst - 2.6.0-rc1
  * chore: add devcontainer for local development (#2258)
* Wed Aug  7 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.4.15 (no releas 2.4.14):
  * feat: console remote url by @CristhianF7 in #2249
  * feat: ignore launch up install when debug is on by @CristhianF7
    in #2250
  * Run Go tests on commits by @patrickdappollonio in #2251
  * Apply gofmt, golangci-lint. by @patrickdappollonio in #2253
  * chore: add support for editorconfig by @mrsimonemms in #2242
* Thu Jul 18 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.4.13:
  * feat: install kubefirst pro flag (#2236)
  * fix: a missing break (#2247)
  * feat: runtime migration to kubefirst-api (#2246)
* Tue Jul 16 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.4.12:
  * chore: bump launch up version (#2244)
  * chore: bump runtime version (#2237)
* Thu Jul  4 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.4.11:
  * chore: bump launch up version (#2223)
  * added bubbletea quit method instead of os exit
* Tue Jun 11 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.4.10:
  * pinning cli kubefist chart to 2.4.10 (#2198)
  * bump runtime and kubefirst-api to latest in kubefirst cli
    (#2197)
  * chore: changing brews spec for repository name
* Mon Jun 10 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.4.9:
  * goreleaser version 2
  * --clean replaces --rm-dist
  * Update releaser.yaml
  * adopting v2.4.9 in cli (#2194)
  * add the docs links for Akamai + K3s (#2183)
  * docs: fix a typo (#2186)
  * docs: add a thank you for our contributors & a special note for
    Drummy (#2185)
  * feat: akamai estimated time (#2117)
  * fix: close GOOGLE_APPLICATION_CREDENTIALS file (#2179)
* Thu May  2 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.4.8:
  * v2.4.8 adopts gitlab catalog fix and trifecta upgrade (#2169)
  * Fix the signing commits check GitHub workflow for PRs from
    forks (#2167)
* Mon Apr 29 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.4.7:
  * adoption of 2.4.7 chart (#2166)
* Tue Apr 23 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.4.6:
  * adopt 2.4.6 chart (#2159)
* Sat Apr 20 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.4.5:
  * 2.4.5 adoption in cli (#2158)
* Sat Apr 20 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.4.4:
  * 2.4.4 - adoption of talos distro on civo github and civo gitlab
    management clusters (#2157)
  * chore: add Akamai + k3s clouds choices & fix typo (#2139)
* Thu Mar 21 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.4.3:
  * pinning cluster zero to 2.4.3 (#2134)
* Mon Mar 18 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.4.2:
  * 2.4.2 chart adoption in cli (#2131)
  * setting helm chart to 242rc1 (#2130)
  * adding known host check for gitlab / github (#2129)
* Sat Mar 16 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.4.1:
  * preparing cli for 2.4.1 (#2121)
  * fix: version check (#2120)
* Sat Mar 16 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.4.0:
  * release v2.4.0 (#2118)
  * fix: k3d and ci flag (#2116)
  * use local and missing types (#2107)
  * changing to rc27 for launch up (#2115)
  * fix: config version (#2113)
  * chore: bump launch (#2111)
  * feat: cluster role binding (#2110)
  * fix: env var (#2109)
  * update kubefirst-api package (#2108)
  * adds catalogApps to function call (#2106)
  * update runtime package (#2105)
  * add akamai cloud support (#2104)
  * feat: add k3s cmd (#1875)
* Sat Feb 24 2024 opensuse_buildservice@ojkastl.de
- Update to version 2.3.8:
  * chore: bump launch version v2.3.8 (#2100)
  * chore: bump launch version rc76 (#2099)
  * feat: post install catalog apps (#2090)
  * feat: SKIP_ARGOCD_LAUNCH env var set to true will suppress
    argocd launch when development (#2080)
  * fix: support ngrok authtoken (#2074)
  * feat: logs (#2069)
  * chore: update licence years to include 2024 (#2063)
  * ci: remove a non-working UX project automation workflow (#2059)
  * ci: using the right token for
    srggrs/assign-one-project-github-action (#2056)
  * ci: fix the project URL for
    srggrs/assign-one-project-github-action (#2054)
  * ci: update assign-one-project-github-action version + fix token
    name (#2051)
  * ci: add a workflow to automatically add UX issues into the
    project (#2048)
  * refactor: updated the console 0 destroy message for clarity
    (#1986)
  * chore: make installation type for marketplace generic for bug
    report (#1980)
  * feat: subdomain flag for cloudflare (#1976)
  * fix: add quouta command to the bubbletea blacklist (#1967)
* Thu Dec 14 2023 kastl@b1-systems.de
- Update to version 2.3.7:
  no changelog available, only a diff
  https://github.com/kubefirst/kubefirst/compare/v2.3.6...v2.3.7
* Thu Dec 14 2023 kastl@b1-systems.de
- Update to version 2.3.6:
  * fix: git label and repo (#1957)
  * chore: bump chart version (#1956)
  * chore: adopt latest metrics-client (#1955)
  * chore: bump chart version (#1954)
  * feat: move digitial ocean out of beta (#1952)
  * add node type and node count flags to aws, civo, google, and
    vultr
  * return telemetry event
  * remove close func that is no longer there
  * WIP. add node type/ node count to cli
  * feat: remove the ability to run cluster zero on atlas (#1944)
  * chore: put back dummy account information after tests (#1947)
  * chore: add exit code for aws assume script (#1946)
  * chore: add a script to assume AWS role more easily (#1945)
  * chore: add a Terraform plan to create an admin role in AWS to
    be assumed (#1943)
  * chore: add a warning about creating 1 GH issue per
    bug/suggestion. (#1939)
  * fix: hanging unknown commands (#1930)
  * chore: bump launch version (#1929)
  * fix: k3d branding (#1926)
  * last try to fix the new combobox on bug report (#1923)
  * chore: fixing the bug template (#1922)
  * add a question about gitops-template being a fork or not
    (#1919)
  * fix: update messaging for launch up success for something
    clearer (#1912)
  * fix: hanging commands (#1904)
  * chore: add a 'none specific option for OS' (#1899)
  * fix: improve getting KUBECONFIG command for Civo (#1886)
* Thu Nov  2 2023 kastl@b1-systems.de
- Update to version 2.3.5:
  * chore: bump version (#1890)
* Wed Nov  1 2023 kastl@b1-systems.de
- Update to version 2.3.4:
  * fix: 1879 - launch up can depend on api default for
    isClusterZero (#1880)
  * chore: add a field for the OS for bug reports (#1882)
  * chore: add an installation option for Civo Marketplace in bug
    report (#1881)
  * chore: remove other installation instructions as moved to the
    docs (#1873)
* Fri Oct 27 2023 kastl@b1-systems.de
- Update to version 2.3.3:
  * feat: 2.3.3 adopt latest gitops-template (#1871)
  * fix: cloudflare token, error handling for cluster creation
    (#1870)
* Wed Oct 25 2023 kastl@b1-systems.de
- Update to version 2.3.2:
  * fix: styles json (#1868)
* Wed Oct 25 2023 kastl@b1-systems.de
- Update to version 2.3.1:
  * pin cli to 2.3.1 (#1867)
  * chore: remove previous E2E tests (#1860)
* Tue Oct 24 2023 kastl@b1-systems.de
- Update to version 2.3.0:
  * 2.3.0 adoption (#1866)
  * 2.3.1 adoption in cli (#1865)
  * feat: adopt rc56 (#1864)
  * chore: remove prerun so we can support non-docker environments
    (#1863)
  * rc55 plus improved launch up env vars (#1862)
  * fix: error handling (#1859)
  * docs: fix Linux installation for other architecture than amd
    (#1856)
  * docs(README.md): fix asdf config (#1844)
  * docs: add beta clouds (#1858)
  * fix docs link in the readme (#1848)
  * fix: debug validation (#1854)
  * fixes bad error ref (#1855)
  * fix refernced metrics (#1853)
  * fix: adopt latest segment implementation in kubefirst (#1852)
  * feat k3d (#1846)
  * adopt rc42 in kubefirst launch (#1843)
  * adjustments needed for launch up to install latest macro
    (#1841)
  * core: add DNS information to bugs issue template (#1834)
  * feat: cli refactor (#1832)
  * ci: upgrade the DavidAnson/markdownlint-cli2-action action
    (#1828)
  * ci: add a Markdown link checker action (#1818)
  * ci: don't include PR number is commit linting lenght for titles
    (#1822)
  * ci: update config for markdown check for deprecated setting
    (#1821)
  * feat: civo create using launch up (#1820)
  * docs: add info on running kubefirst CLI with the latest
    gitops-template (#1819)
  * ci: add a workflow to validate Markdown syntax (#1817)
  * add a SECURITY.md file for security issues (close #883) (#1814)
  * fix: runtime version fixes detokenization
  * fix: aws containerRegistryURL metaphor duplication (#1797)
  * ci: add a workflow to check if the commits are signed (#1803)
  * chore: update launch version rc15 (#1800)
  * chore: update launch version (#1799)
  * runtime adjustment (#1798)
  * fix: fix the type of v1alpha1ArgocdApplication (#1796)
  * Api convention (#1795)
  * fix: changing to API convention from runtime (#1794)
  * cloudflare origin issuer adjustment (#1792)
  * fix: restructure flag caps
  * fix: enforce lowercase
* Tue Oct 10 2023 Johannes Kastl <kastl@b1-systems.de>
- new package kubefirst: CLI for the KubeFirst GitOps
  Infrastructure & Application Delivery Platform
